# # ex - archive extractor
# # usage: ex <file>
ex ()
{
  if [ -f $1 ] ; then
    case $1 in
      *.tar.bz2)   tar xjf $1   ;;
      *.tar.gz)    tar xzf $1   ;;
      *.tar.xz)    tar xJf $1   ;;
      *.bz2)       bunzip2 $1   ;;
      *.rar)       unrar x $1   ;;
      *.gz)        gunzip $1    ;;
      *.tar)       tar xf $1    ;;
      *.tbz2)      tar xjf $1   ;;
      *.tgz)       tar xzf $1   ;;
      *.zip)       unzip $1     ;;
      *.Z)         uncompress $1;;
      *.7z)        7z x $1      ;;
      *)           echo "'$1' cannot be extracted via ex()" ;;
    esac
  else
    echo "'$1' is not a valid file"
  fi
}

pacmanupdate ()
{
  echo -n "Enter the country code for the mirrorlist you want to use (default: CZ): "
  read -t 10 update;
  if [ -z "$update" ]; then
    update=CZ;
  fi
  sudo reflector -c $update -f 12 -l 10 -n 12 --save /etc/pacman.d/mirrorlist;
}

alias ls='ls --color'
alias ll='ls -l'
# ls, the common ones I use a lot shortened for rapid fire usage
alias l='ls -lFh'     #size,show type,human readable
alias la='ls -lAFh'   #long list,show almost all,show type,human readable
alias lr='ls -tRFh'   #sorted by date,recursive,show type,human readable
alias lt='ls -ltFh'   #long list,sorted by date,show type,human readable
alias ll='ls -l'      #long list
alias ldot='ls -ld .*'
alias lS='ls -1FSsh'
alias lart='ls -1Fcart'
alias lrt='ls -1Fcrt'

alias zshrc='${=EDITOR} ~/.zshrc' # Quick access to the ~/.zshrc file

alias grep='grep --color'
alias sgrep='grep -R -n -H -C 5 --exclude-dir={.git,.svn,CVS} '

alias t='tail -f'

# Command line head / tail shortcuts
alias -g H='| head'
alias -g T='| tail'
alias -g G='| grep'
alias -g L="| less"
alias -g M="| most"
alias -g LL="2>&1 | less"
alias -g CA="2>&1 | cat -A"
alias -g NE="2> /dev/null"
alias -g NUL="> /dev/null 2>&1"
alias -g P="2>&1| pygmentize -l pytb"

alias dud='du -d 1 -h'
alias duf='du -sh *'
alias fd='find . -type d -name'
alias ff='find . -type f -name'

alias h='history'
alias hgrep="fc -El 0 | grep"
alias help='man'
alias p='ps -f'
alias sortnr='sort -n -r'
alias unexport='unset'

# Use trash instead of rm if available
if command -v trash &> /dev/null
then
  alias rm='trash'
else
  alias rm='rm -i'
fi

alias cp='cp -i'
alias mv='mv -i'

# alias update-grub='sudo grub-mkconfig -o /boot/grub/grub.cfg'
alias firefox='GTK_USE_PORTAL=1 firefox'

alias cls="clear"

alias sshc='ssh-connect'

# Kitty binds
if [ "$TERM" = "xterm-kitty" ]; then
  alias ssh="kitty +kitten ssh"
  alias icat="kitty +kitten icat"
  alias d="kitty +kitten diff"
  alias get="kitty +kitten transfer"
  alias put="kitty +kitten transfer --direction=upload"
  alias kclip="kitty +kitten clipboard"
fi

if command -v lsd &> /dev/null
then
  alias ls="lsd"
fi
